@@ -1,5 +1,6 @@
 package Bio::Protease::Types;
-our $VERSION = '1.092570';
+our $VERSION = '1.093150';
+
 
 
 # ABSTRACT: Specific types for Bio::Protease
@@ -32,7 +33,6 @@ __PACKAGE__->meta->make_immutable;
 
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -41,7 +41,7 @@ Bio::Protease::Types - Specific types for Bio::Protease
 
 =head1 VERSION
 
-version 1.092570
+version 1.093150
 
 =head1 DESCRIPTION
 
@@ -49,11 +49,9 @@ This module defines specific types and type coercions to be used by
 Bio::Protease. It should not be used by end users, nor is necessary to
 subclass from Bio::ProteaseI.
 
-
-
 =head1 AUTHOR
 
-  Bruno Vecchi <vecchi.b@gmail.com>
+Bruno Vecchi <vecchi.b gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -62,6 +60,5 @@ This software is copyright (c) 2009 by Bruno Vecchi.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
